==> mktcenter-service-1.0.0-vg-20210401.124947-23-sources.jar: com/bizvane/mktcenterservice/interfaces/ActivityService.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.bizvane.centerstageservice.models.po.SysCheckPo;
import com.bizvane.couponfacade.models.vo.CouponSendMemberListResponseVO;
import com.bizvane.couponfacade.models.vo.SendCouponSimpleRequestVO;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.vo.WxChannelInfoVo;
import com.bizvane.messagefacade.models.vo.MemberMessageVO;
import com.bizvane.messagefacade.models.vo.SysSmsConfigVO;
import com.bizvane.mktcenterservice.models.bo.*;
import com.bizvane.mktcenterservice.models.po.MktMessagePO;
import com.bizvane.mktcenterservice.models.po.OpendCardActivityMumberBO;
import com.bizvane.mktcenterservice.models.vo.*;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageInfo;
import org.apache.poi.ss.formula.functions.T;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @author chen.li
 * @date on 2018/7/6 19:49
 * @description
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public interface ActivityService {

    /**
     * 禁用/停止活动
     *
     * @param vo
     * @return
     */
    public ResponseData<Integer> updateActivityById(ActivityVO vo, SysAccountPO sysAccountPO);

    /**
     * 活动审核
     *
     * @param
     * @return
     */
    public ResponseData<Integer> checkActivityById(SysCheckPo po, SysAccountPO sysAccountPO);

    /**
     * 小程序端活动列表
     *
     * @param vo
     * @return
     */
    public ResponseData<List<ActivityVO>> getActivityList(ActivityVO vo);

    public ResponseData<List<ActivityVO>> getActivityListNew(ActivityVO vo);

    /**
     * 查询效果分析统计
     *
     * @param bo
     * @return
     */
    public ResponseData<CtivityAnalysisBO> getActivityAnalysisCountpage(ActivityAnalysisCountBO bo, PageForm pageForm);

    public void sendMessage(List<MktMessagePO> messageVOList, MemberInfoModel memberInfo, ActivityVO activityVO);

    public void sendMessageWX(List<MktMessagePO> messageVOList, MemberInfoModel memberInfo, ActivityVO activityVO);

    public void sendMessageDX(List<MktMessagePO> messageVOList, MemberInfoModel memberInfo, ActivityVO activityVO);

    public void sendPoints(ActivitySmartVO vo, AwardBO awardBO, MemberInfoModel memberInfo);

    public void sendShort(MktMessagePO mktMessagePO, AwardBO awardBO, SysSmsConfigVO sysSmsConfigVO, MemberInfoModel memberInfo);

    public void sendWx(MktMessagePO mktMessagePO, AwardBO awardBO, MemberMessageVO memberMessageVO, MemberInfoModel memberInfo, ActivitySmartVO vo);

    /**
     * 同步发送微信模板消息
     * @param mktMessagePO
     * @param memberInfo
     * @param brandName
     * @param MarketingName
     * @return
     */
    public ResponseData<T> syncSendWxNew(MktMessagePO mktMessagePO, MemberInfoModel memberInfo, String brandName, String MarketingName);

    public void sendCoupon(ActivitySmartVO vo, MemberInfoModel memberInfo);

    public void sendCouponNew(ActivitySmartVO vo, AwardBO awardBO, SendCouponSimpleRequestVO sendCouponSimpleRequestVO, MemberInfoModel memberInfo);

    public void sendRegisterWx(List<MktMessagePO> messageVOList, WxChannelInfoVo wxChannelInfoVo, ActivityVO activityVO);

    public void sendDx(List<MktMessagePO> messageVOList, MemberInfoModel memberInfo,ActivityVO activityVO);

    /**
     * 活动、任务效果分析“发行优惠券”添加会员明细弹框；
     *
     * @return
     */
    ResponseData<PageInfo<CouponSendMemberListResponseVO>> findCouponSendResultActivity(Long id, Integer type, SysAccountPO stageUser,
                                                                                        PageForm pageForm, String name, String cardNo);

    /**
     * 前端调用店铺
     */
    public List<Long> getActivityWhiteStoreIds(WhiteStoreVO vo);

    /**
     * 扫描二维码进行判断
     *
     * @param vo
     * @return
     */
    public ResponseData<Integer> judgeMember(JudgeMemberVO vo);

    /**
     * 禁用活动(通用)
     */
    public ResponseData<Integer> checkCommonActivity(SysCheckPo po, SysAccountPO sysAccountPO);

    /**
     * 根据企业品牌获取可以展示在小程序上的活动
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    List<ActivityVO> getActivityForApplet(Long sysCompanyId, Long brandId);

    /**
     * 修改执行中的活动,目前仅仅支持修改适用门店
     * @param bo
     * @param sysAccountPO
     * @return
     */
    ResponseData<String> updateActivityDoing(ActivityBO bo, SysAccountPO sysAccountPO);

    /**
     * 获取签到活动详情
     * @param vo
     * @param pageForm
     * @return
     */
    ResponseData<MktSignInRecordVo> listSignInActivityRecordVo(MktSignInRecordVo vo, PageForm pageForm);

    /**
     * 导出签到活动详情
     * @param vo
     * @param request
     * @return
     */
    ResponseData exportSignInActivityRecordVo(MktSignInRecordVo vo, HttpServletRequest request);

    ResponseData<CtivityAnalysisBO> getActivityRegistrationAnalysisCountpage(ActivityAnalysisCountBO bo, PageForm pageForm);


    /**
     * 小程序端活动列表 vg
     *
     * @param vo
     * @return
     */
     ResponseData<List<ActivityVO>> getActivityListVg(ActivityVO vo);

    /**
     * 检查当前活动会员是否入会
     */
    ResponseData<CheckActivityVo> checkNowActivityIsHaveMember(Long mktActivityId,String memberCode);

    ResponseData<OpendCardActivityMumberBO> getOpenCardActivityNumberListById(Long id);


    /**
     * 检查当前品牌会员是否入会
     */
    ResponseData<CheckActivityVo> checkNowBrandIsHaveMember(Long sysBrandId,String memberCode);


    ResponseData<ImportExcelDataRspVO> importPhoneExcelData(String importUrl,Long sysCompanyId,Long brandId);
}

==> mktcenter-service-1.0.2-vg-20220527.073649-8-sources.jar: com/bizvane/mktcenterservice/interfaces/ActivityService.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.bizvane.centerstageservice.models.po.SysCheckPo;
import com.bizvane.couponfacade.models.vo.CouponSendMemberListResponseVO;
import com.bizvane.couponfacade.models.vo.SendCouponSimpleRequestVO;
import com.bizvane.members.facade.es.pojo.MembersInfoSearchPojo;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.vo.WxChannelInfoVo;
import com.bizvane.messagefacade.models.vo.MemberMessageVO;
import com.bizvane.messagefacade.models.vo.SysSmsConfigVO;
import com.bizvane.mktcenterservice.models.bo.*;
import com.bizvane.mktcenterservice.models.po.MktMessagePO;
import com.bizvane.mktcenterservice.models.po.OpendCardActivityMumberBO;
import com.bizvane.mktcenterservice.models.vo.*;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageInfo;
import org.apache.poi.ss.formula.functions.T;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @author chen.li
 * @date on 2018/7/6 19:49
 * @description
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public interface ActivityService {

    /**
     * 禁用/停止活动
     *
     * @param vo
     * @return
     */
    public ResponseData<Integer> updateActivityById(ActivityVO vo, SysAccountPO sysAccountPO);

    /**
     * 活动审核
     *
     * @param
     * @return
     */
    public ResponseData<Integer> checkActivityById(SysCheckPo po, SysAccountPO sysAccountPO);

    /**
     * 小程序端活动列表
     *
     * @param vo
     * @return
     */
    public ResponseData<List<ActivityVO>> getActivityList(ActivityVO vo);

    public ResponseData<List<ActivityVO>> getActivityListNew(ActivityVO vo);

    /**
     * 查询效果分析统计
     *
     * @param bo
     * @return
     */
    public ResponseData<CtivityAnalysisBO> getActivityAnalysisCountpage(ActivityAnalysisCountBO bo, PageForm pageForm);

    public void sendMessage(List<MktMessagePO> messageVOList, MemberInfoModel memberInfo, ActivityVO activityVO);

    public void sendMessageWX(List<MktMessagePO> messageVOList, MemberInfoModel memberInfo, ActivityVO activityVO);

    public void sendMessageDX(List<MktMessagePO> messageVOList, MemberInfoModel memberInfo, ActivityVO activityVO);

    public void sendPoints(ActivitySmartVO vo, AwardBO awardBO, MembersInfoSearchPojo memberInfo);

    public void sendShort(MktMessagePO mktMessagePO, AwardBO awardBO, SysSmsConfigVO sysSmsConfigVO, MembersInfoSearchPojo memberInfo);

    public void sendWx(MktMessagePO mktMessagePO, AwardBO awardBO, MemberMessageVO memberMessageVO, MemberInfoModel memberInfo, ActivitySmartVO vo);

    /**
     * 同步发送微信模板消息
     * @param mktMessagePO
     * @param memberInfo
     * @param brandName
     * @param MarketingName
     * @return
     */
    public ResponseData<T> syncSendWxNew(MktMessagePO mktMessagePO, MemberInfoModel memberInfo, String brandName, String MarketingName);

    public void sendCoupon(ActivitySmartVO vo, MembersInfoSearchPojo memberInfo);

    public void sendCouponNew(ActivitySmartVO vo, AwardBO awardBO, SendCouponSimpleRequestVO sendCouponSimpleRequestVO, MemberInfoModel memberInfo);

    public void sendRegisterWx(List<MktMessagePO> messageVOList, WxChannelInfoVo wxChannelInfoVo, ActivityVO activityVO);

    public void sendDx(List<MktMessagePO> messageVOList, MemberInfoModel memberInfo,ActivityVO activityVO);

    /**
     * 活动、任务效果分析“发行优惠券”添加会员明细弹框；
     *
     * @return
     */
    ResponseData<PageInfo<CouponSendMemberListResponseVO>> findCouponSendResultActivity(Long id, Integer type, SysAccountPO stageUser,
                                                                                        PageForm pageForm, String name, String cardNo);

    /**
     * 前端调用店铺
     */
    public List<Long> getActivityWhiteStoreIds(WhiteStoreVO vo);

    /**
     * 扫描二维码进行判断
     *
     * @param vo
     * @return
     */
    public ResponseData<Integer> judgeMember(JudgeMemberVO vo);

    /**
     * 禁用活动(通用)
     */
    public ResponseData<Integer> checkCommonActivity(SysCheckPo po, SysAccountPO sysAccountPO);

    /**
     * 根据企业品牌获取可以展示在小程序上的活动
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    List<ActivityVO> getActivityForApplet(Long sysCompanyId, Long brandId);

    /**
     * 修改执行中的活动,目前仅仅支持修改适用门店
     * @param bo
     * @param sysAccountPO
     * @return
     */
    ResponseData<String> updateActivityDoing(ActivityBO bo, SysAccountPO sysAccountPO);

    /**
     * 获取签到活动详情
     * @param vo
     * @param pageForm
     * @return
     */
    ResponseData<MktSignInRecordVo> listSignInActivityRecordVo(MktSignInRecordVo vo, PageForm pageForm);

    /**
     * 导出签到活动详情
     * @param vo
     * @param request
     * @return
     */
    ResponseData exportSignInActivityRecordVo(MktSignInRecordVo vo, HttpServletRequest request);

    ResponseData<CtivityAnalysisBO> getActivityRegistrationAnalysisCountpage(ActivityAnalysisCountBO bo, PageForm pageForm);


    /**
     * 小程序端活动列表 vg
     *
     * @param vo
     * @return
     */
     ResponseData<List<ActivityVO>> getActivityListVg(ActivityVO vo);

    /**
     * 检查当前活动会员是否入会
     */
    ResponseData<CheckActivityVo> checkNowActivityIsHaveMember(Long mktActivityId,String memberCode);

    ResponseData<OpendCardActivityMumberBO> getOpenCardActivityNumberListById(Long id);


    /**
     * 检查当前品牌会员是否入会
     */
    ResponseData<CheckActivityVo> checkNowBrandIsHaveMember(Long sysBrandId,String memberCode);


    ResponseData<ImportExcelDataRspVO> importPhoneExcelData(String importUrl,Long sysCompanyId,Long brandId);
}
